平时在开发移动端项目的时候，点击事件具有 300ms 的延迟，这使得用户体验非常的不好，我一般都用 `fastClick` 第三方插件来处理的。

在使用 `fastClick` 时候有一些坑，值得注意。

## FastClick用法

* Javascript原生

```javascript
if ('addEventListener' in document) {
    document.addEventListener('DOMContentLoaded', function() {
        FastClick.attach(document.body)
    }, false)
}
```

* jQuery

```javascript
$(function() {
    FastClick.attach(document.body);
})
```

* 类似Common JS的模块系统方式

先下载 `fastClick` 第三方模块，然后项目中引入

```javascript
var attachFastClick = require('fastclick')  // require() 引入fastclick 后返回fastclick.attach() 方法
attachFastClick(document.body)
```

## 不需要使用fastclick的情况

* PC端, FastClick 只在移动端监听；

* Android版Chrome 32+浏览器，如果设置`viewport meta`的值为`width=device-width`，这种情况下浏览器会马上出发点击事件，不会延迟300毫秒。

```html
<meta name="viewport" content="width=device-width, initial-scale=1">
```

* 所有版本的Android Chrome浏览器，如果设置 `viewport meta` 的值有`user-scalable=no`，浏览器也是会立即触发点击事件。

* IE11+浏览器设置了css的属性`touch-action: manipulation`，它会在某些标签（a，button等）禁止双击事件，IE10的为`-ms-touch-action: manipulation`

**注意**：

对于页面上不需要使用`fastclick`来立刻触发点击事件的元素在元素标签的class上添加`needsclick` 即可。

## 踩坑总结

`fastClick` 与 常见的 `video.js` 插件，`input` 输入框默认行为等有冲突，比如 在使用 video.js 插件的页面中使用 fastClick 会导致 video.js 的播放音量等按钮失效，这时候我们需要根据实际需求来为相应元素监听原始click事件，取消 `fastClick` 内部监听的点击事件，只需在要取消的元素上加 特定类名：`needsclick` 。
